@@ -1,4 +1,5 @@
 from django.core.urlresolvers import reverse
+from django.db.models import Model
 from django.test import TestCase, Client
 from django.utils.functional import curry
 
@@ -11,11 +12,14 @@ class AdrestTestCase(TestCase):
         self.client = Client()
 
     def reverse(self, resource, **kwargs):
+        kwargs = dict((k, getattr(v, "pk", v)) for k, v in kwargs.iteritems())
         return reverse('api-%s-%s' % (str(self.api), resource.meta.urlname), kwargs=kwargs)
 
     def get_resource(self, resource, method='get', data=None, key=None, **kwargs):
         uri = self.reverse(resource, **kwargs)
         method = getattr(self.client, method)
+        if isinstance(key, Model):
+            key = key.key
         return method(uri, data=data or dict(), HTTP_AUTHORIZATION=key)
 
     put_resource = curry(get_resource, method='put')
